@@ -53,7 +53,7 @@ sub find_modules ($;$) {
 		foreach my $section (@$sections) {
 			my $subdir = "$dir/$section";
 			next unless -d $subdir;
-			my @files = map { glob "$subdir/$_*.pm" } ("", "*/", "*/*/");
+			my @files = map { glob "$subdir/$_*.pm" } ("", "*/", "*/*/", "*/*/*/");
 			push @files, "$subdir.pm" if -f "$subdir.pm";
 			foreach my $file (@files) {
 				my $class = substr($file, length($dir) + 1);
